@@ -76,7 +76,7 @@ use Moose 0.89;
 use Log::Log4perl qw(:easy);
 Log::Log4perl->easy_init( { level => $INFO, layout => '%-5p - %m%n' } );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 has 'meshfile' => ( is => 'rw', isa => 'Str', required => 1 );
 has 'heading' => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
@@ -93,7 +93,9 @@ sub parse() {
 	$count->{syns} = 0;
 
 	while (<$fh>) {
-		chomp;
+		# multiplatform chomp
+		# this will also rtrim the line
+		s/\s+$//;
 
 		# initialise
 		if (/^\*NEWRECORD/) {
@@ -102,9 +104,11 @@ sub parse() {
 			$id       = undef;
 		}
 
+		DEBUG '<' . $_ . '>';
+
 		# save on new line
 		if (/^$/) {
-			LOGDIE 'Something went wrong. Could not parse heading\'s label.'
+			LOGDIE 'Could not parse heading\'s label.'
 			  unless defined $label;
 			$count->{headings}++;
 			WARN "Duplicate heading found for $id"
@@ -140,13 +144,16 @@ sub parse() {
 	}
 	close $fh;
 
+	LOGDIE 'Could not parse any headings.'
+	  unless defined $count->{headings};
+
 	INFO "Loaded "
 	  . $count->{headings}
 	  . " headings and "
 	  . $count->{syns}
 	  . " synonyms";
-	  
-	  1;
+
+	1;
 }
 
 1;
